//
//  ActivitiesViewController.swift
//  App-RK-Wearable
//
//  Created by Luis Mora on 14/10/24.
//

import UIKit

class ActivitiesViewController: UIViewController, BluetoothManagerDelegate {
    
    @IBOutlet weak var getDataButton: UIButton!
    @IBOutlet weak var stateLabel: UILabel!
    @IBOutlet weak var dataLabel: UILabel!
    @IBOutlet weak var connectButton: UIButton!
    @IBOutlet weak var endActivityButton: UIButton!
    @IBOutlet weak var startActivityButton: UIButton!
    @IBOutlet weak var disconnectButton: UIButton!
    
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        title = "Actividades"
        
        BluetoothManager.shared.delegate = self
    }
    
    @IBAction func connectButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.startScanning()
    }
    
    @IBAction func disconnectButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.disconnect()
    }
    
    @IBAction func startActivityButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.sendCommand("MEASURE")
    }
    @IBAction func endActivityButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.sendCommand("IDLE")
    }
    
    @IBAction func cancelActivityButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.sendCommand("CANCEL")
    }
    @IBAction func getDataButtonTapped(_ sender: UIButton) {
        BluetoothManager.shared.sendCommand("SEND_DATA")
    }
    
    // BluetoothManagerDelegate - Actualizar estado de conexión
    func didUpdateConnectionStatus(isConnected: Bool) {
        let status = isConnected ? "Conectado": "Desconectado"
        print("Estado de conexión: \(status)")
        print("En activities view controller")
        DispatchQueue.main.async {
            self.stateLabel.text = "Estado: " + status
        }
    }
    
    // BluetoothManagerDelegate - Datos recibidos
    func didReceiveData(_ data: String) {
        print("Datos recibidos: \(data)")
        print("En activities view controller")
        if self.isViewLoaded && self.view.window != nil {
            DispatchQueue.main.asyncAfter(deadline: .now() + 0.5) {
                self.showAlert(title: "Datos del ESP32", mmessage: "Datos recibidos: \(data)")
            }
        } else {
            print("La vista NO está en la jerarquía de vistas")
        }
    }
    
    // BluetoothManagerDelegate - Datos recibidos
    func didReceiveData(fromCharacteristic uuid: String, data: String) {
        if uuid == "beb5483e-36e1-4688-b7f5-ea07361b26a8" {
            print("Comando recibido: \(data)")
        } else if uuid == "beb5483e-36e1-4688-b7f5-ea07361b26b1" {
            print("Datos del MAX3010: \(data)")
        } else if uuid == "beb5483e-36e1-4688-b7f5-ea07361b26b2" {
            print("Datos del MPU6050: \(data)")
        }
    }
}
